# Changelog

## [0.1.0a1](https://github.com/OpenVoiceOS/ovos-PHAL/tree/0.1.0a1) (2024-09-10)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-PHAL/compare/V0.0.5...0.1.0a1)

**Merged pull requests:**

- chore:semver\_automations [\#36](https://github.com/OpenVoiceOS/ovos-PHAL/pull/36) ([JarbasAl](https://github.com/JarbasAl))



\* *This Changelog was automatically generated by [github_changelog_generator](https://github.com/github-changelog-generator/github-changelog-generator)*
